@@ -250,7 +250,7 @@ class Snyk(SCAScanTool):
             if "identifiers" in issue["issueData"]:
                 public_id_list = issue["issueData"]["identifiers"]["CVE"]
             else:
-                public_id_list = []
+                public_id_list = [issue["id"]]
             for public_id in public_id_list:
                 tmp_issue = IssueReport(
                     issue_project_name, issue_project_version, public_id
