@@ -266,15 +266,9 @@ class Whitesource(SCAScanTool):
         return component_list
 
     def get_issues_by_vulnerability(
-        self, json_data, v_lib_name="TBD", v_lib_verision="TBD"
-    ):
+        self, json_data, v_lib_name, v_lib_verision):
         issue_list = []
         for v in json_data["vulnerabilities"]:
-            if v_lib_name == "TBD" or v_lib_verision == "TBD":
-                v_lib_name = v["library"]["groupId"]
-                if v_lib_name == "":
-                    v_lib_name = library["name"].rsplit('-',1)[0]
-                v_lib_verision = v["library"]["version"]
             v_name = v["name"]
             tmp_issue = IssueReport(v_lib_name, v_lib_verision, v_name)
             if v.__contains__("severity"):
@@ -289,9 +283,13 @@ class Whitesource(SCAScanTool):
     def get_issues_by_project_inventory(self, json_data):
         issue_list = []
         for library in json_data["libraries"]:
-            l_name = library["groupId"]
+            l_type = library["type"]
+            if l_type == "MAVEN_ARTIFACT":
+                l_name = f"{library['groupId']}:{library['artifactId']}"
+            else:
+                l_name = library["groupId"]
             if l_name == "":
-                l_name = library["name"].rsplit('-',1)[0]
+                l_name = library["name"].rsplit('-', 1)[0]
             l_version = library["version"]
             tmp_issue_list = self.get_issues_by_vulnerability(
                 library, l_name, l_version
